;; tile-maker.scm   GIMP2.4
 
(define (script-fu-tile-maker width height size bump color random)
 (let* ((image (car(gimp-image-new width height 0)))
        (background (car (gimp-layer-new image width height 0 "Tile" 100 NORMAL)))
        (line-channel (car (gimp-channel-new image width height "Line" 0 '(0 0 0))))
        (old-fg (car (gimp-context-get-foreground))) 
        (old-bg (car (gimp-context-get-background))) 
        (bumpmap) (random-layer)
       )

  (gimp-image-undo-disable image)
  (gimp-context-set-foreground color)
  (gimp-context-set-background '(0 0 0))

  (gimp-image-add-channel image line-channel 0)
  (gimp-edit-fill line-channel 1)
  (plug-in-grid 1 image line-channel 
						(/ size 20) size 0 '(255 255 255) 255 
			            (/ size 20) size 0 '(255 255 255) 255 
						             0 0 0 '(255 255 255) 255)

  (set! bumpmap (car (gimp-channel-copy line-channel)))
  (gimp-image-add-channel image bumpmap 0)
  (plug-in-gauss-iir2 1 image bumpmap (/ size 10) (/ size 10))
  (plug-in-normalize 1 image bumpmap)

  (gimp-image-add-layer image background 0)
  (gimp-edit-fill background 0)
  (plug-in-bump-map 1 image background bumpmap
                            135 30 bump 0 0 0 125 TRUE TRUE 0)

  (gimp-selection-load line-channel)
  (gimp-selection-grow image 1)
  (gimp-bucket-fill background BG-BUCKET-FILL NORMAL 15 0 FALSE 0 0)

  (gimp-selection-load line-channel)
  (gimp-edit-fill background 2)
  (gimp-selection-none image)

  (if (= random TRUE)(begin
    (set! random-layer (car (gimp-layer-new image width height 1 "Random Brightness" 100 OVERLAY)))
    (gimp-image-add-layer image random-layer -1)
    (plug-in-solid-noise 1 image random-layer FALSE FALSE 1 1 16 16)
    (plug-in-pixelize 1 image random-layer size)
    (plug-in-normalize 1 image random-layer)
    (gimp-layer-set-opacity random-layer 60)
    (gimp-image-flatten image)
  ))

  (gimp-image-remove-channel image line-channel)
  (gimp-image-remove-channel image bumpmap)
  (gimp-context-set-foreground old-fg)
  (gimp-context-set-background old-bg)
  (gimp-image-undo-enable image)
  (gimp-display-new image)
 )
)

(script-fu-register "script-fu-tile-maker"
 "Tile Maker..."
 "Create a tile image"
 "Hachiro"
 "Hachiro"
 "2005/7/3"
 ""
 SF-ADJUSTMENT _"Image width"  '(300 10 2000 1 10 0 1)
 SF-ADJUSTMENT _"Image height" '(300 10 2000 1 10 0 1) 
 SF-ADJUSTMENT _"Tile Size"    '(60 20 1000 1 10 0 1) 
 SF-ADJUSTMENT _"Bump Level"   '(3 1 5 1 1 0 1) 
 SF-COLOR      _"Color"        '(100 160 255)
 SF-TOGGLE     _"Random Brightness"  FALSE
)

(script-fu-menu-register "script-fu-tile-maker"
 "<Image>/File/Create/Patterns")

